@@ -110,15 +110,19 @@ class BaseModelEngine:
                 labels_dataset = self.load_labels(dataset)
                 input_features = []
                 labels = []
-                for input_dataset in inputs_dataset:
-                    input_features.append(input_dataset.to(device))
-                for label_dataset in labels_dataset:
-                    labels.append(label_dataset.to(device))
+                if type(inputs_dataset) is list or type(inputs_dataset) is tuple:
+                    for input_dataset in inputs_dataset:
+                        input_features.append(input_dataset.to(device))
+                else:
+                    input_features = inputs_dataset.to(device)
+                if type(labels_dataset) is list or type(labels_dataset) is tuple:
+                    for label_dataset in labels_dataset:
+                        labels.append(label_dataset.to(device))
+                else:
+                    labels = labels_dataset.to(device)
                 outputs = model(*input_features)
                 if len(outputs) == 1:
                     outputs = outputs[0]
-                if len(labels) == 1:
-                    labels = labels[0]
                 focal_loss = self.criterion(outputs=outputs, labels=labels)
                 focal_acc = self.accuracy(outputs=outputs, labels=labels)
                 # focal_loss = self.criterion(outputs=tuple(outputs), labels=tuple(labels))
